@@ -161,8 +161,8 @@ fn trim<O: BitOrder, T: BitStore>(
 ) -> &BitSlice<O, T> {
   let stop = |b: &bool| *b != to_trim;
   let front = bits.iter().by_ref().position(stop).unwrap_or(0);
-  let back = bits.iter().by_ref().rposition(stop).unwrap_or(0);
-  &bits[front ..= back]
+  let back = bits.iter().by_ref().rposition(stop).map_or(0, |p| p + 1);
+  &bits[front .. back]
 }
 # assert_eq!(trim(bits![0, 0, 1, 1, 0, 1, 0], false), bits![1, 1, 0, 1]);
 ```
@@ -1852,7 +1852,7 @@ where
 	///
 	/// # Returns
 	///
-	/// The distance in (semantic) bits betwen the heads of each region. The
+	/// The distance in (semantic) bits between the heads of each region. The
 	/// value is positive when `other` is higher in the address space than
 	/// `self`, and negative when `other` is lower in the address space than
 	/// `self`.
@@ -2131,7 +2131,7 @@ where
 	///
 	/// # API Differences
 	///
-	/// This returns `*mut BitSlice`, which is the equivalont of `*mut [T]`
+	/// This returns `*mut BitSlice`, which is the equivalent of `*mut [T]`
 	/// instead of `*mut T`. The pointer encoding used requires more than one
 	/// CPU word of space to address a single bit, so there is no advantage to
 	/// removing the length information from the encoded pointer value.
@@ -2330,7 +2330,7 @@ where
 	/// boundaries.
 	///
 	/// This splits `self` into the memory locations that it partially fills and
-	/// the memory locatinos that it completely fills. The locations that are
+	/// the memory locations that it completely fills. The locations that are
 	/// completely filled may be accessed without any `bitvec`-imposed alias
 	/// conditions, while the locations that are only partially filled are left
 	/// unchanged.
